Functions
- get
- Get the cached configuration, assuming it has been loaded via
load_from_env. Panics if called before initialization. - load_
from_ env - Load configuration from the environment and cache it for subsequent calls.
load_from_env.
Panics if called before initialization.